<?php
/*
* 2007-2014 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2014 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*
*  @author PrestaShop SA / revision by EAGLEMEDIA.de
*/

if (!defined('_PS_VERSION_'))
	exit;

class SendToAFriendPro extends Module
{
	private $_html = '';
	private $_postErrors = array();
	public $context;

	function __construct($dontTranslate = false)
 	{
 	 	$this->name = 'sendtoafriendpro';
		$this->version = '1.6.2';
		$this->author = 'EAGLEMEDIA.de';
 	 	$this->tab = 'front_office_features';
		$this->need_instance = 0;
		$this->secure_key = Tools::encrypt($this->name);

		$this->bootstrap = true;
		parent::__construct();

		$this->displayName = $this->l('Send to a Friend module pro');
		$this->description = $this->l('Allows customers to send a product link to a friend. Additions with settings to spam and flood prevention.');
		$this->ps_versions_compliancy = array('min' => '1.6', 'max' => '1.6.99.99');
		$this->confirmUninstall = $this->l('Are you sure you want to delete all these details ?');
	}

	public function install()
	{
		if( !parent::install() 
		OR  !$this->registerHook('extraLeft') 
		OR  !$this->registerHook('header') 
		OR  !Configuration::updateValue('STF_PREVENT_BLOCK1', '@qq.com, yahoo.cn, @0, @1, @2,')
		OR  !Configuration::updateValue('STF_PREVENT_BLOCK2', '')
		OR  !Configuration::updateValue('STF_PREVENT_BLOCK3', '') )
		    return false;
		return true;
	}

	public function uninstall()
	{
		if( !parent::uninstall() 
		OR  !$this->unregisterHook('header') 
		OR  !$this->unregisterHook('extraLeft') 
	  	OR  !Configuration::deleteByName('STF_PREVENT_BLOCK1')   
		OR  !Configuration::deleteByName('STF_PREVENT_BLOCK2') 
		OR  !Configuration::deleteByName('STF_PREVENT_BLOCK3') )
		    return false;
		return true;
	}

    #
	#
	#
	
	public function postProcess()
	{
		if( Tools::isSubmit('stf_pro')
		AND Configuration::updateValue('STF_PREVENT_BLOCK1', Tools::getValue('STF_PREVENT_BLOCK1'))
		AND Configuration::updateValue('STF_PREVENT_BLOCK2', Tools::getValue('STF_PREVENT_BLOCK2'))
		AND Configuration::updateValue('STF_PREVENT_BLOCK3', Tools::getValue('STF_PREVENT_BLOCK3')) )
            return $this->displayConfirmation($this->l('The settings have been updated.'));
	}
	
	public function getContent()
	{			
		return $this->postProcess().$this->renderForm();
	}

	public function renderForm()
	{
		$fields_form = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Settings'),
					'icon' => 'icon-cogs'
				),
				'input' => array(
					array(
						'type' => 'textarea',				
						'label' => $this->l('Check by address pattern , 1'),
						'name' => 'STF_PREVENT_BLOCK1',
						'class' => 'banip_',
						'desc' => $this->l('Write this form : @qq.com, yahoo.cn, @0, @1, @2, ...')
					),					
					array(
						'type' => 'textarea',				
						'label' => $this->l('Check by ip addresses , 2'),
						'name' => 'STF_PREVENT_BLOCK2',
						'class' => 'banip_',
						'desc' => $this->l('Write this form : 0.0.0.0, 9.9.9.9, ...')
					),
					array(
						'type' => 'textarea',				
						'label' => $this->l('Check by product ids , 3'),
						'name' => 'STF_PREVENT_BLOCK3',
						'class' => 'banip_',
						'desc' => $this->l('Write this form : 3, 12, 27, ...')
					)
				),
				'submit' => array(
					'title' => $this->l('Update')
				)
			)
		);

		$helper = new HelperForm();
		$helper->show_toolbar = false;
		$helper->table =  $this->table;
		$lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->default_form_language = $lang->id;
		$helper->module = $this;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
		$helper->identifier = $this->identifier;
		$helper->submit_action = 'stf_pro';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->tpl_vars = array(
			'uri' => $this->getPathUri(),
			'fields_value' => $this->getConfigFieldsValues(),
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id
		);
        
	    $donate_form = '
            <div class="cookiebanner text-center">
                '.$this->l('Have a look at my modules for PrestaShop').' -
                <a href="https://eaglemedia.de/cms.php?s=prestashop-module" target="_blank">MODULE</a>
                <p class="clear"> </p>
                '.$this->l('Made with').' <i class="icon-heart"></i> '.$this->l('by').'
                <a href="http://eaglemedia.de" target="_blank">EAGLEMEDIA</a>
                <p class="clear"><br/> </p>

                <form action="https://www.paypal.com/donate" method="post" target="_blank">
                    <input type="hidden" name="hosted_button_id" value="ALLRFT5RZJVHN" />
                    <input type="image" src="https://www.paypalobjects.com/de_DE/DE/i/btn/btn_donateCC_LG.gif" 
                           border="0" name="submit" title="PayPal - The safer, easier way to pay online!" alt="Donate with PayPal button" />

                    <img alt="" border="0" src="https://www.paypal.com/de_DE/i/scr/pixel.gif" width="1" height="1" />
                </form>
                <p class="clear"><br/><br/> </p>	
            </div>
        ';

		return $donate_form.$helper->generateForm(array($fields_form));
	}	

	public function getConfigFieldsValues()
	{
		
		$fields = array(		
			'STF_PREVENT_BLOCK1' => Tools::getValue('STF_PREVENT_BLOCK1', Configuration::get('STF_PREVENT_BLOCK1')),     
            'STF_PREVENT_BLOCK2' => Tools::getValue('STF_PREVENT_BLOCK2', Configuration::get('STF_PREVENT_BLOCK2')),			
			'STF_PREVENT_BLOCK3' => Tools::getValue('STF_PREVENT_BLOCK3', Configuration::get('STF_PREVENT_BLOCK3'))
		);

		return $fields;
	} 	
	
	#
	#
	#

	public function hookExtraLeft($params)
	{
		/* Product informations */
		$product = new Product((int)Tools::getValue('id_product'), false, $this->context->language->id);
		$image = Product::getCover((int)$product->id);

		$this->context->smarty->assign(array(
			'stf_product' => $product,
			'stf_product_cover' => (int)$product->id.'-'.(int)$image['id_image'],
			'stf_secure_key' => $this->secure_key
		));

		return $this->display(__FILE__, 'sendtoafriendpro-ajax.tpl');
	}

	public function hookHeader($params)
	{
		$this->page_name = Dispatcher::getInstance()->getController();
		if ($this->page_name == 'product')
		{
			$this->context->controller->addCSS($this->_path.'css/sendtoafriendpro.css', 'all');
			$this->context->controller->addJS($this->_path.'js/sendtoafriendpro.js');
		}
	}
}